kafkaclient

package module
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 26, 2024 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type KafkaClient

type KafkaClient struct {
	// contains filtered or unexported fields
}

func NewKafkaClient

func NewKafkaClient(broker string, maxRetries int, retryInterval time.Duration, config *sarama.Config, logger Logger) (*KafkaClient, error)

NewKafkaClient creates a new KafkaClient instance.

func (*KafkaClient) Close

func (kc *KafkaClient) Close() error

Close closes the connection to Kafka.

func (*KafkaClient) IsReady

func (kc *KafkaClient) IsReady() bool

IsReady returns the readiness state of the Kafka client.

func (*KafkaClient) SendBatch

func (kc *KafkaClient) SendBatch(batch []*sarama.ProducerMessage, topic string) error

SendBatch sends a batch of messages to Kafka with retries.

func (*KafkaClient) StartBatchSender

func (kc *KafkaClient) StartBatchSender(ringBuffer *kafkabuff.RingBuffer, batchSize int, interval time.Duration, kafkaTopic string)

StartBatchSender starts sending messages from the ring buffer to Kafka.

type Logger added in v0.2.0

type Logger interface {
	Debugf(format string, args ...interface{})
	Infof(format string, args ...interface{})
	Warnf(format string, args ...interface{})
	Errorf(format string, args ...interface{})
}

Logger interface

type StdLogger added in v0.2.0

type StdLogger struct{}

func (*StdLogger) Debugf added in v0.2.0

func (l *StdLogger) Debugf(format string, args ...interface{})

func (*StdLogger) Errorf added in v0.2.0

func (l *StdLogger) Errorf(format string, args ...interface{})

func (*StdLogger) Infof added in v0.2.0

func (l *StdLogger) Infof(format string, args ...interface{})

func (*StdLogger) Warnf added in v0.2.0

func (l *StdLogger) Warnf(format string, args ...interface{})

Jump to